package com.ruoyi.system.service.impl;

import com.ruoyi.system.domain.SysUnitConvert;
import com.ruoyi.system.mapper.SysUnitConvertMapper;
import com.ruoyi.system.service.ISysUnitConvertService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 单位换算Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-10-08
 */
@Service
public class SysUnitConvertServiceImpl implements ISysUnitConvertService 
{
    @Autowired
    private SysUnitConvertMapper sysUnitConvertMapper;

    /**
     * 查询单位换算
     * 
     * @param id 单位换算主键
     * @return 单位换算
     */
    @Override
    public SysUnitConvert selectSysUnitConvertById(Long id)
    {
        return sysUnitConvertMapper.selectSysUnitConvertById(id);
    }

    /**
     * 查询单位换算列表
     * 
     * @param sysUnitConvert 单位换算
     * @return 单位换算
     */
    @Override
    public List<SysUnitConvert> selectSysUnitConvertList(SysUnitConvert sysUnitConvert)
    {
        return sysUnitConvertMapper.selectSysUnitConvertList(sysUnitConvert);
    }

    /**
     * 新增单位换算
     * 
     * @param sysUnitConvert 单位换算
     * @return 结果
     */
    @Override
    public int insertSysUnitConvert(SysUnitConvert sysUnitConvert)
    {
        return sysUnitConvertMapper.insertSysUnitConvert(sysUnitConvert);
    }

    /**
     * 修改单位换算
     * 
     * @param sysUnitConvert 单位换算
     * @return 结果
     */
    @Override
    public int updateSysUnitConvert(SysUnitConvert sysUnitConvert)
    {
        return sysUnitConvertMapper.updateSysUnitConvert(sysUnitConvert);
    }

    /**
     * 批量删除单位换算
     * 
     * @param ids 需要删除的单位换算主键
     * @return 结果
     */
    @Override
    public int deleteSysUnitConvertByIds(Long[] ids)
    {
        return sysUnitConvertMapper.deleteSysUnitConvertByIds(ids);
    }

    /**
     * 删除单位换算信息
     * 
     * @param id 单位换算主键
     * @return 结果
     */
    @Override
    public int deleteSysUnitConvertById(Long id)
    {
        return sysUnitConvertMapper.deleteSysUnitConvertById(id);
    }

    /**
     * 查询单位换算
     * @param unitType 单位换算
     * @param unitOrder 单位换算
     * @param baseUnit 单位换算
     * @return 单位换算
     */

    @Override

    public SysUnitConvert selectSysUnitConvertUnitByTypeOrder(String unitType,Long unitOrder, String baseUnit) {
        return sysUnitConvertMapper.selectSysUnitConvertUnitByTypeOrder(unitType, unitOrder,baseUnit);
    }

}
